essential classes for arianna station protocol

Revision:
4:9f7e3fb5394d
Parent:
3:fc27e024ad2d
Child:
5:ef4c7dfbf8cf
--- a/SnHeaderFrame.h	Thu Sep 05 22:31:20 2013 +0000
+++ b/SnHeaderFrame.h	Sat Oct 05 04:40:47 2013 +0000
@@ -19,6 +19,8 @@
     static const uint8_t    kStatusCode      = 0x10;
     static const uint8_t    kFileCode        = 0x20;
     static const uint8_t    kFilenameCode    = 0x23;
+    static const uint8_t    kFileTrgStrtCode = 0x24;
+    static const uint8_t    kFileTrgStopCode = 0x25;
     static const uint8_t    kFileNevtsCode   = 0x26;
     static const uint8_t    kFileNpwrsCode   = 0x28;
     static const uint8_t    kFileHeadrCode   = 0x2A;
@@ -37,6 +39,8 @@
     static const uint8_t    kHnShOkDelAlCode = 0x68;
     static const uint8_t    kHnShFailPrtCode = 0x6A;
     static const uint8_t    kHnShFailNonCode = 0x6C;
+    static const uint8_t    kHnShDemandCode  = 0x6E;
+    static const uint8_t    kHnShNoReplyCode = 0x6F;
     static const uint8_t    kPowerCode       = 0x70;
     static const uint8_t    kHeartbeatCode   = 0x78;
     static const uint8_t    kNoConfigCode    = 0x80;
@@ -60,7 +64,7 @@
     bool WriteTo(T& x,
                  const uint8_t msgCode,
                  const uint32_t msgLen) {
         // expect 'x' to be a MODSERIAL or a char const*
         x = SnBitUtils::WriteTo(x, msgCode);
         x = SnBitUtils::WriteTo(x, msgLen);
         return true;
@@ -60,7 +64,7 @@
                  const uint8_t msgCode,
                  const uint32_t msgLen) {
-        // expect 'x' to be a MODSERIAL or a char const*
+        // expect 'x' to be a MODSERIAL or a char const* or a FILE*
         x = SnBitUtils::WriteTo(x, msgCode);
         x = SnBitUtils::WriteTo(x, msgLen);